--
-- PlayerToggleAnimation
-- Specialization for PlayerToggleAnimation
--
-- @author:		Michi77
-- @date:		10/07/16
-- @version:	v1.0
-- @history:	v1.0 - initial version
--
-- free for non-commercial usage

PlayerToggleAnimation = {};

function PlayerToggleAnimation.prerequisitesPresent(specializations)
    return true;
end;

function PlayerToggleAnimation:load(xmlFile)
	self.playerCallback = SpecializationUtil.callSpecializationsFunction("playerCallback");
	
	self.pToggleAnimation = {};
	local i = 0;
	while true do
		local key = string.format("vehicle.PlayerToggleAnimation.toggleAnimation(%d)",i);
		if not hasXMLProperty(xmlFile, key) then
			break;
		end;
		
		local trigger = Utils.indexToObject(self.components, getXMLString(xmlFile, key.. "#trigger"));
		if trigger == nil then
			break;
		end;

		i = i + 1;
		self.pToggleAnimation[i] = {};
		self.pToggleAnimation[i].trigger = trigger;
		self.pToggleAnimation[i].animation = getXMLString(xmlFile, key .. "#animation");
		self.pToggleAnimation[i].i18n = getXMLString(xmlFile, key .. "#i18n");
		self.pToggleAnimation[i].types = getXMLString(xmlFile, key .. "#types");
		self.pToggleAnimation[i].animState = -1;
		self.pToggleAnimation[i].plIR = false;
		addTrigger( trigger, "playerCallback", self );
	end;
end;
function PlayerToggleAnimation:delete()
	for i,j in pairs(self.pToggleAnimation) do
		if j.trigger ~= nil then
			removeTrigger(j.trigger);
		end;
	end;
end;
function PlayerToggleAnimation:readStream(streamId, connection)
	for i=1, #self.pToggleAnimation do
		self.pToggleAnimation[i].curTrans = streamReadFloat32(streamId);
	end;
end;
function PlayerToggleAnimation:writeStream(streamId, connection)
	for i=1, #self.pToggleAnimation do
		streamWriteFloat32(streamId, self.pToggleAnimation[i].curTrans);
	end;
end;
function PlayerToggleAnimation:mouseEvent(posX, posY, isDown, isUp, button)
end;
function PlayerToggleAnimation:keyEvent(unicode, sym, modifier, isDown)
end;
function PlayerToggleAnimation:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		for i,j in pairs(self.pToggleAnimation) do
			local s = Utils.getNoNil(getXMLFloat(xmlFile, key..string.format("#pToggleAnimationState%d",i) ), 1);
			self.pToggleAnimation[i].animState = s;
			self:playAnimation(self.pToggleAnimation[i].animation, self.pToggleAnimation[i].animState, nil, true);
		end;
	end;
    return BaseMission.VEHICLE_LOAD_OK;
end;

function PlayerToggleAnimation:getSaveAttributesAndNodes(nodeIdent)
    local attributes = '';
	for i,j in pairs(self.pToggleAnimation) do
		attributes = attributes .. string.format('pToggleAnimationState%d="%s" ', i, tostring(j.animState));
	end;
    return attributes, nil;
end;
function PlayerToggleAnimation:update(dt)
	local plIR = false;
	local id = 0;
	for i,j in pairs(self.pToggleAnimation) do
		if j.plIR then
			id = i;
			plIR = true;
			break;
		end;
	end;
	if plIR then
		g_currentMission:addHelpButtonText(g_i18n:getText(self.pToggleAnimation[id].i18n), InputBinding.PLAYER_TOGGLE_ANIMATION);
		if InputBinding.hasEvent(InputBinding.PLAYER_TOGGLE_ANIMATION) then
			if self.pToggleAnimation[id].types == nil then
				if (self.pToggleAnimation[id].animState == 1) then
					self.pToggleAnimation[id].animState = -1;
				else
					self.pToggleAnimation[id].animState = 1;
				end;
				self:playAnimation(self.pToggleAnimation[id].animation, self.pToggleAnimation[id].animState, nil, true); 
			elseif self.pToggleAnimation[id].types == "chopper" then
				if self.isStrawEnabled then 
					self.pToggleAnimation[id].i18n = "ENABLE_STRAW_SWATH";
				else 
					self.pToggleAnimation[id].i18n = "DISABLE_STRAW_SWATH"; 
				end;
			
				if self.chopperSwitchAvailable then 
					if self.lastValidInputFruitType ~= FruitUtil.FRUITTYPE_UNKNOWN then 
						local fruitDesc = FruitUtil.fruitIndexToDesc[self.lastValidInputFruitType]; 
						if fruitDesc.hasWindrow then 
							self:setIsStrawEnabled(not self.isStrawEnabled); 
						else 
							self.toggleChopperWarningTime = g_currentMission.time + 2000; 
						end; 
					else 
						self:setIsStrawEnabled(not self.isStrawEnabled); 
					end; 
				end;
			elseif self.pToggleAnimation[id].types == "grain" then
				self:openGui();
				self.isOpenedGui = true;
			end
		end;
	end;
end;

function PlayerToggleAnimation:updateTick(dt)
end;

function PlayerToggleAnimation:draw()
end;

function PlayerToggleAnimation:playerCallback(triggerId, otherId, onEnter, onLeave, onStay)
	local id = 0;
	for i,j in pairs(self.pToggleAnimation) do
		if j.trigger == triggerId then
			id = i;
			break;
		end;
	end;
	
	if id ~= 0 then
		if onEnter and g_currentMission.controlPlayer and g_currentMission.player ~= nil and otherId == g_currentMission.player.rootNode then
			self.pToggleAnimation[id].plIR = true;
		elseif onLeave then
			self.pToggleAnimation[id].plIR = false;
		end;
	end;
end;